==> tepez-static-website-0.4.0.tgz: package/gulp/tasks/dev.js <==
'use strict';
const Gulp = require('gulp');
const RunSequence = require('run-sequence');
const BrowserSync = require('browser-sync');
const Karma = require('karma');
const _ = require('lodash');

const BuildUtil = require('../util/build');
const Browserify = require('./browserify');
const TasksUtils = require('../util/utils');
const Config = TasksUtils.gulpConfig;


Gulp.task('dev', function(callback) {
  TasksUtils.isDev = true;
  RunSequence('build', 'dev-watch', /*'dev-unit-test',*/ callback);
});


Gulp.task('dev-watch', ['dev-watchify','dev-browserSync'], function() {

  Gulp.watch(Config.build.lintJs.src, Config.build.lintJs.srcOpts, ['build-lint-js']);

  Gulp.watch(Config.build.sass.src,   ['build-sass']);

  let imageBundles = Config.build.images;
  if (imageBundles) {
    if (!_.isArray(imageBundles)) {
      imageBundles = [imageBundles];
    }
    imageBundles.forEach((bundle) => {
      Gulp.watch(bundle.src, bundle.srcOpts, () => {
        BuildUtil.buildImages(bundle);
      });
    });
  }

  let copyBundle = Config.build.copy;
  if (copyBundle) {
    if (!_.isArray(copyBundle)) {
      copyBundle = [copyBundle];
    }
    copyBundle.forEach((bundle) => {
      Gulp.watch(bundle.src, bundle.srcOpts, () => {
        BuildUtil.buildCopy(bundle);
      });
    });
  }

  // Watchify will watch and recompile our JS, so no need to gulp.watch it
  Gulp.watch(['./src/docs/**/*', Config.build.locale.src], ['build-static-site']);

});

Gulp.task('dev-watchify', function() {
  return Browserify.browserifyTask();
});

Gulp.task('dev-browserSync', function() {
  BrowserSync(Config.dev.browserSync);
});

Gulp.task('dev-unit-test', function(done) {
  Karma.server.start(Config.dev.unitTest.settings, function(exitCode) {
    if (exitCode === 0) {
      done();
    } else {
      done(new Error('Karma exited with code ' + exitCode));
    }
  });
});

==> tepez-static-website-0.7.2.tgz: package/gulp/tasks/dev.js <==
'use strict';
const Gulp = require('gulp');
const RunSequence = require('run-sequence');
const BrowserSync = require('browser-sync');
const Karma = require('karma');
const _ = require('lodash');

const BuildUtil = require('../util/build');
const Browserify = require('./browserify');
const TasksUtils = require('../util/utils');
const Config = TasksUtils.gulpConfig;


Gulp.task('dev', function(callback) {
  TasksUtils.isDev = true;
  RunSequence('build', 'dev-watch', /*'dev-unit-test',*/ callback);
});

Gulp.task('dev-watch', ['dev-watchify','dev-browserSync'], function() {
  if (Config.build.lintJs) {
    Gulp.watch(Config.build.lintJs.src, Config.build.lintJs.srcOpts, ['build-lint-js']);
  }

  if (Config.build.sass) {
    Gulp.watch(Config.build.sass.src, ['build-sass']);
  }


  const imageBundles = TasksUtils.arrayOrEmpty(Config.build.images);
  if (imageBundles) {
    imageBundles.forEach((bundle) => {
      Gulp.watch(bundle.src, bundle.srcOpts, () => {
        BuildUtil.buildImages(bundle);
      });
    });
  }

  const copyBundles = TasksUtils.arrayOrEmpty(Config.build.copy);
  if (copyBundles) {
    copyBundles.forEach((bundle) => {
      Gulp.watch(bundle.src, bundle.srcOpts, () => {
        BuildUtil.buildCopy(bundle);
      });
    });
  }

  // Watchify will watch and recompile our JS, so no need to gulp.watch it
  Gulp.watch(['./src/docs/**/*'], ['build-static-site']);
});

Gulp.task('dev-watchify', function() {
  return Browserify.browserifyTask();
});

Gulp.task('dev-browserSync', function() {
  BrowserSync(Config.dev.browserSync);
});

Gulp.task('dev-unit-test', function(done) {
  if (!Config.dev.unitTest) return done();

  Karma.server.start(Config.dev.unitTest.settings, function(exitCode) {
    if (exitCode === 0) {
      done();
    } else {
      done(new Error('Karma exited with code ' + exitCode));
    }
  });
});
